@@ -1,6 +1,6 @@
 /*
  * rd_stats.c: Read system statistics
- * (C) 1999-2023 by Sebastien GODARD (sysstat <at> orange.fr)
+ * (C) 1999-2024 by Sebastien GODARD (sysstat <at> orange.fr)
  *
  ***************************************************************************
  * This program is free software; you can redistribute it and/or modify it *
@@ -2846,7 +2846,7 @@ int read_softnet(struct stats_softnet *st_softnet, __nr_t nr_alloc,
 		}
 		else {
 			/* cpu_id not present in file */
-			while ((!(online_cpu_bitmap[(cpu - 1) >> 3] & (1 << ((cpu - 1) & 0x07)))) && (cpu < nr_alloc)) {
+			while (!IS_CPU_SET(online_cpu_bitmap, cpu - 1) && (cpu < nr_alloc)) {
 				cpu++;
 			}
 		}
